@@ -1,8 +1,8 @@
 import ast
 import typing
-import re
 
 from typedpy import Array, Map, Structure
+from typedpy.type_info_getter import get_type_info
 
 INDENT = " " * 4
 
@@ -241,21 +241,20 @@ def get_models(
     return classes, functions
 
 
-def extract_attributes_from_init(source):
+def extract_attributes_from_init(source, locals_attrs, additional_classes):
+    def _get_normalized_dict(args):
+        return dict([x if len(x) == 2 else x + ["Any"] for x in args])
+
     root = ast.parse(source.strip())
     info = _get_function_info(root.body[0])
     self_name = info.positional_args[0]
     positional_args = [x.split(":") for x in info.positional_args[1:]]
-    normalized_positional_args = dict(
-        [x if len(x) == 2 else x + ["Any"] for x in positional_args]
-    )
+    normalized_positional_args = _get_normalized_dict(positional_args)
     keyword_only_args_without_default = [
         x.split("=")[0] for x in info.keyword_only_args
     ]
     keyword_only_args = [x.split(":") for x in keyword_only_args_without_default]
-    normalized_keyword_only_args = dict(
-        [x if len(x) == 2 else x + ["Any"] for x in keyword_only_args]
-    )
+    normalized_keyword_only_args = _get_normalized_dict(keyword_only_args)
     type_by_param = {**normalized_positional_args, **normalized_keyword_only_args}
 
     func_body = root.body[0].body
@@ -272,5 +271,19 @@ def extract_attributes_from_init(source):
                 attribute_name = node.targets[0].attr
                 if isinstance(node.value, ast.Name) and node.value.id in type_by_param:
                     res[attribute_name] = type_by_param[node.value.id]
+                else:
+                    try:
+                        value = eval(ast.unparse(node.value), locals_attrs)
+                        the_type = get_type_info(
+                            value.__class__, locals_attrs, additional_classes
+                        )
+                        res[attribute_name] = the_type
+                    except:
+                        res[attribute_name] = "Any"
+
+        elif isinstance(node, ast.AnnAssign):
+            annotation = ast.unparse(node.annotation)
+            attribute_name = node.target.attr
+            res[attribute_name] = annotation
 
     return res
